@@ -28,6 +28,7 @@ from .EntityTypeDto import EntityTypeDto
 from .KeyDto import KeyDto
 from .MosaicMetadataTransactionBodyBuilder import MosaicMetadataTransactionBodyBuilder
 from .NetworkTypeDto import NetworkTypeDto
+from .UnresolvedAddressDto import UnresolvedAddressDto
 from .UnresolvedMosaicIdDto import UnresolvedMosaicIdDto
 
 
@@ -38,7 +39,7 @@ class EmbeddedMosaicMetadataTransactionBuilder(EmbeddedTransactionBuilder):
         mosaicMetadataTransactionBody: Mosaic metadata transaction body.
     """
 
-    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, targetPublicKey: KeyDto, scopedMetadataKey: int, targetMosaicId: UnresolvedMosaicIdDto, valueSizeDelta: int, value: bytes):
+    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, targetAddress: UnresolvedAddressDto, scopedMetadataKey: int, targetMosaicId: UnresolvedMosaicIdDto, valueSizeDelta: int, value: bytes):
         """Constructor.
         Args:
             size: Entity size.
@@ -46,14 +47,14 @@ class EmbeddedMosaicMetadataTransactionBuilder(EmbeddedTransactionBuilder):
             version: Entity version.
             network: Entity network.
             type: Entity type.
-            targetPublicKey: Metadata target public key.
+            targetAddress: Metadata target address.
             scopedMetadataKey: Metadata key scoped to source, target and type.
             targetMosaicId: Target mosaic identifier.
             valueSizeDelta: Change in value size in bytes.
             value: Difference between existing value and new value \note when there is no existing value, new value is same this value \note when there is an existing value, new value is calculated as xor(previous-value, value).
         """
         super().__init__(size, signerPublicKey, version, network, type)
-        self.mosaicMetadataTransactionBody = MosaicMetadataTransactionBodyBuilder(targetPublicKey, scopedMetadataKey, targetMosaicId, valueSizeDelta, value)
+        self.mosaicMetadataTransactionBody = MosaicMetadataTransactionBodyBuilder(targetAddress, scopedMetadataKey, targetMosaicId, valueSizeDelta, value)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> EmbeddedMosaicMetadataTransactionBuilder:
@@ -68,14 +69,14 @@ class EmbeddedMosaicMetadataTransactionBuilder(EmbeddedTransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         mosaicMetadataTransactionBody = MosaicMetadataTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[mosaicMetadataTransactionBody.getSize():]
-        return EmbeddedMosaicMetadataTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, mosaicMetadataTransactionBody.targetPublicKey, mosaicMetadataTransactionBody.scopedMetadataKey, mosaicMetadataTransactionBody.targetMosaicId, mosaicMetadataTransactionBody.valueSizeDelta, mosaicMetadataTransactionBody.value)
+        return EmbeddedMosaicMetadataTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, mosaicMetadataTransactionBody.targetAddress, mosaicMetadataTransactionBody.scopedMetadataKey, mosaicMetadataTransactionBody.targetMosaicId, mosaicMetadataTransactionBody.valueSizeDelta, mosaicMetadataTransactionBody.value)
 
-    def getTargetPublicKey(self) -> KeyDto:
-        """Gets metadata target public key.
+    def getTargetAddress(self) -> UnresolvedAddressDto:
+        """Gets metadata target address.
         Returns:
-            Metadata target public key.
+            Metadata target address.
         """
-        return self.mosaicMetadataTransactionBody.getTargetPublicKey()
+        return self.mosaicMetadataTransactionBody.getTargetAddress()
 
     def getScopedMetadataKey(self) -> int:
         """Gets metadata key scoped to source, target and type.
