@@ -25,6 +25,7 @@ from __future__ import annotations
 from .GeneratorUtils import GeneratorUtils
 from .EmbeddedTransactionBuilder import EmbeddedTransactionBuilder
 from .EntityTypeDto import EntityTypeDto
+from .FinalizationPointDto import FinalizationPointDto
 from .KeyDto import KeyDto
 from .LinkActionDto import LinkActionDto
 from .NetworkTypeDto import NetworkTypeDto
@@ -39,7 +40,7 @@ class EmbeddedVotingKeyLinkTransactionBuilder(EmbeddedTransactionBuilder):
         votingKeyLinkTransactionBody: Voting key link transaction body.
     """
 
-    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, linkedPublicKey: VotingKeyDto, linkAction: LinkActionDto):
+    def __init__(self, size: int, signerPublicKey: KeyDto, version: int, network: NetworkTypeDto, type: EntityTypeDto, linkedPublicKey: VotingKeyDto, startPoint: FinalizationPointDto, endPoint: FinalizationPointDto, linkAction: LinkActionDto):
         """Constructor.
         Args:
             size: Entity size.
@@ -48,10 +49,12 @@ class EmbeddedVotingKeyLinkTransactionBuilder(EmbeddedTransactionBuilder):
             network: Entity network.
             type: Entity type.
             linkedPublicKey: Linked public key.
+            startPoint: Start finalization point.
+            endPoint: End finalization point.
             linkAction: Link action.
         """
         super().__init__(size, signerPublicKey, version, network, type)
-        self.votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder(linkedPublicKey, linkAction)
+        self.votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder(linkedPublicKey, startPoint, endPoint, linkAction)
 
     @classmethod
     def loadFromBinary(cls, payload: bytes) -> EmbeddedVotingKeyLinkTransactionBuilder:
@@ -66,7 +69,7 @@ class EmbeddedVotingKeyLinkTransactionBuilder(EmbeddedTransactionBuilder):
         bytes_ = bytes_[superObject.getSize():]
         votingKeyLinkTransactionBody = VotingKeyLinkTransactionBodyBuilder.loadFromBinary(bytes_)  # kind:CUSTOM1
         bytes_ = bytes_[votingKeyLinkTransactionBody.getSize():]
-        return EmbeddedVotingKeyLinkTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, votingKeyLinkTransactionBody.linkedPublicKey, votingKeyLinkTransactionBody.linkAction)
+        return EmbeddedVotingKeyLinkTransactionBuilder(superObject.size, superObject.signerPublicKey, superObject.version, superObject.network, superObject.type, votingKeyLinkTransactionBody.linkedPublicKey, votingKeyLinkTransactionBody.startPoint, votingKeyLinkTransactionBody.endPoint, votingKeyLinkTransactionBody.linkAction)
 
     def getLinkedPublicKey(self) -> VotingKeyDto:
         """Gets linked public key.
@@ -75,6 +78,20 @@ class EmbeddedVotingKeyLinkTransactionBuilder(EmbeddedTransactionBuilder):
         """
         return self.votingKeyLinkTransactionBody.getLinkedPublicKey()
 
+    def getStartPoint(self) -> FinalizationPointDto:
+        """Gets start finalization point.
+        Returns:
+            Start finalization point.
+        """
+        return self.votingKeyLinkTransactionBody.getStartPoint()
+
+    def getEndPoint(self) -> FinalizationPointDto:
+        """Gets end finalization point.
+        Returns:
+            End finalization point.
+        """
+        return self.votingKeyLinkTransactionBody.getEndPoint()
+
     def getLinkAction(self) -> LinkActionDto:
         """Gets link action.
         Returns:
